==> moodle-1.4.3-pgsql.tgz: moodle/lang/ja/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004121600)


$string['calendar'] = '';
$string['calendarheading'] = '$a ';
$string['clickhide'] = 'ɽ';
$string['clickshow'] = 'ɽ';
$string['confirmeventdelete'] = 'ˤΥ٥ȤƤǤ?';
$string['courseevents'] = '٥';
$string['day'] = '';
$string['dayview'] = '1ʬɽ';
$string['daywithnoevents'] = '٥Ȥޤ';
$string['default'] = 'ǥե';
$string['deleteevent'] = '٥Ȥκ';
$string['detailedmonthview'] = 'ɽܺ';
$string['dstadjusttime'] = '֤';
$string['dstat'] = ':';
$string['dstby'] = ':';
$string['dstdefaultpresetname'] = 'DSTץꥻå';
$string['dsthumanreadable'] = ' $a->activate_month  $a->activate_index  $a->activate_weekday ˻֤ $a->offset minutes $a->direction  $a->deactivate_month  $a->deactivate_index $a->deactivate_weekday ޤ³ޤ';
$string['dstof'] = ':';
$string['dstonthe'] = '';
$string['dstpresetactivated'] = 'Ŭѳ';
$string['dstpresetadjusttime'] = 'Ĵ';
$string['dstpresetdeactivated'] = 'Ŭѽλ';
$string['dstpresetname'] = 'ץꥻå̾';
$string['durationminutes'] = ' ( ʬ )';
$string['durationnone'] = '̵';
$string['durationuntil'] = 'λ:';
$string['editevent'] = '٥ȤԽ';
$string['errorbeforecoursestart'] = 'γˤϥ٥ȤϿǤޤ';
$string['errorinvaliddate'] = 'դ˴ְ㤤ޤ';
$string['errorinvalidminutes'] = ' ( ʬ ) 1999δ֤ǻꤷƤ';
$string['errorinvalidrepeats'] = '٥Ȥ1999δ֤ǻꤷƤ';
$string['errornodescription'] = 'ϤƤ';
$string['errornoeventname'] = '̾ΤϤƤ';
$string['eventdate'] = '';
$string['eventdescription'] = '';
$string['eventduration'] = '';
$string['eventendtime'] = 'λ';
$string['eventinstanttime'] = '';
$string['eventkind'] = '٥Ȥμ';
$string['eventname'] = '̾';
$string['eventrepeat'] = '֤';
$string['eventsfor'] = '$a ٥';
$string['eventstarttime'] = '';
$string['eventtime'] = '';
$string['eventview'] = '٥Ⱦܺ';
$string['expired'] = 'ֽλ';
$string['explain_dstpreset'] = 'ɤϰDST ( ƻ )Ѥ뤫ɥåץ˥塼򤹤뤳ȤǤޤ';
$string['explain_dstpresetforced'] = 'ԤˤꤳΥץѹ϶ػߤƤޤ';
$string['explain_lookahead'] = 'Ǥϥ٥ȤľΥ٥ȤȤɽ뤿κꤷޤϰϤ˳Ť륤٥Ȥϡľᥤ٥ȤȤɽޤƤΥ٥ȤΥ塼̤˳Ϥ뤳Ȥ<strong>ݾڤޤ</strong>; ⤷¿ ( ľᥤ٥Ȥκɽװʾ ) Υ٥ȤϿƤϡ֤٤٥Ȥɽޤ';
$string['explain_maxevents'] = 'Ǥľᥤ٥Ȥκɽꤷޤ礭ʿꤷϡľΥ٥Ȥ̤ɽ뤿β̥ڡɬפˤʤޤ';
$string['explain_startwday'] = 'ǤƤη֥ɽˡꤷޤʤƤɽˤʤ褦ꤷƤ';
$string['explain_timeformat'] = '֤ɽ12ɽޤ24ɽ򤹤뤳ȤǤޤǥեȤ򤷤ϡѸ˹碌ƥեޥåȤưŪ򤵤ޤ';
$string['first'] = 'ǽ';
$string['fri'] = '';
$string['friday'] = '';
$string['globalevents'] = 'ΤΥ٥';
$string['gotocalendar'] = 'ذư';
$string['groupevents'] = '롼ץ٥';
$string['hidden'] = 'ɽ';
$string['last'] = 'Ǹ';
$string['manyevents'] = '$a ٥';
$string['mon'] = '';
$string['monday'] = '';
$string['monthlyview'] = 'ɽ';
$string['newevent'] = '٥';
$string['notusingdst'] = 'DST ( ƻ ) Ѥʤ';
$string['noupcomingevents'] = 'ľΥ٥ȤϤޤ';
$string['nth'] = '{$a} ܤ';
$string['oneevent'] = '1 ٥';
$string['pref_dstpreset'] = 'ƻ';
$string['pref_lookahead'] = 'ľᥤ٥Ȥϰ';
$string['pref_maxevents'] = 'ľᥤ٥Ȥκɽ';
$string['pref_startwday'] = 'ν';
$string['pref_timeformat'] = '֥եޥå';
$string['preferences'] = '';
$string['preferences_available'] = 'Ŀ';
$string['repeatnone'] = '̵֤';
$string['repeatweeksl'] = '轵٥ȿ';
$string['repeatweeksr'] = '';
$string['sat'] = '';
$string['saturday'] = '';
$string['shown'] = 'ɽ';
$string['spanningevents'] = 'ʹ楤٥';
$string['sun'] = '';
$string['sunday'] = '';
$string['thu'] = '';
$string['thursday'] = '';
$string['timeformat_12'] = '12 ( / )';
$string['timeformat_24'] = '24';
$string['timeforward'] = 'ʤޤ';
$string['timerewind'] = 'ᤷޤ';
$string['today'] = '';
$string['tomorrow'] = '';
$string['tt_deleteevent'] = '٥Ȥκ';
$string['tt_editevent'] = '٥ȤԽ';
$string['tt_hidecourse'] = '٥ȤɽǤ (  åɽ  )';
$string['tt_hideglobal'] = 'ΤΥ٥ȤɽǤ (  åɽ  )';
$string['tt_hidegroups'] = '롼ץ٥ȤɽǤ (  åɽ  )';
$string['tt_hideuser'] = '桼٥ȤɽǤ (  åɽ  )';
$string['tt_showcourse'] = '٥ȤɽǤ(  åɽ  )';
$string['tt_showglobal'] = 'ΤΥ٥ȤɽǤ (  åɽ  )';
$string['tt_showgroups'] = '롼ץ٥ȤɽǤ (  åɽ  )';
$string['tt_showuser'] = '桼٥ȤɽǤ (  åɽ  )';
$string['tue'] = '';
$string['tuesday'] = '';
$string['typecourse'] = '٥';
$string['typegroup'] = '롼ץ٥';
$string['typesite'] = 'ȥ٥';
$string['typeuser'] = '桼٥';
$string['upcomingevents'] = 'ľᥤ٥';
$string['userevents'] = '桼٥';
$string['wed'] = '';
$string['wednesday'] = '';
$string['yesterday'] = '';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/ja/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005042100)


$string['calendar'] = '';
$string['calendarheading'] = '$a ';
$string['clickhide'] = 'ɽ';
$string['clickshow'] = 'ɽ';
$string['confirmeventdelete'] = 'ˤΥ٥ȤƤǤ?';
$string['courseevents'] = '٥';
$string['dayview'] = '1ʬɽ';
$string['daywithnoevents'] = '٥Ȥޤ';
$string['default'] = 'ǥե';
$string['deleteevent'] = '٥Ȥκ';
$string['detailedmonthview'] = 'ɽܺ';
$string['durationminutes'] = ' ( ʬ )';
$string['durationnone'] = '̵';
$string['durationuntil'] = 'λ:';
$string['editevent'] = '٥ȤԽ';
$string['errorbeforecoursestart'] = 'γˤϥ٥ȤϿǤޤ';
$string['errorinvaliddate'] = 'դ˴ְ㤤ޤ';
$string['errorinvalidminutes'] = ' ( ʬ ) 1999δ֤ǻꤷƤ';
$string['errorinvalidrepeats'] = '٥Ȥ1999δ֤ǻꤷƤ';
$string['errornodescription'] = 'ϤƤ';
$string['errornoeventname'] = '̾ΤϤƤ';
$string['eventdate'] = '';
$string['eventdescription'] = '';
$string['eventduration'] = '';
$string['eventendtime'] = 'λ';
$string['eventinstanttime'] = '';
$string['eventkind'] = '٥Ȥμ';
$string['eventname'] = '̾';
$string['eventrepeat'] = '֤';
$string['eventsfor'] = '$a ٥';
$string['eventstarttime'] = '';
$string['eventtime'] = '';
$string['eventview'] = '٥Ⱦܺ';
$string['expired'] = 'ֽλ';
$string['explain_lookahead'] = 'Ǥϥ٥ȤľΥ٥ȤȤɽ뤿κꤷޤϰϤ˳Ť륤٥Ȥϡľᥤ٥ȤȤɽޤƤΥ٥ȤΥ塼̤˳Ϥ뤳Ȥ<strong>ݾڤޤ</strong>; ⤷¿ ( ľᥤ٥Ȥκɽװʾ ) Υ٥ȤϿƤϡ֤٤٥Ȥɽޤ';
$string['explain_maxevents'] = 'Ǥľᥤ٥Ȥκɽꤷޤ礭ʿꤷϡľΥ٥Ȥ̤ɽ뤿β̥ڡɬפˤʤޤ';
$string['explain_persistflt'] = 'Ԥä硢MoodleϤʤκǿΥ٥ȥե륿򵭲ޤޤʤ󤹤뤿Ӥ˺ǿΥ٥ȤưŪɽޤ';
$string['explain_startwday'] = 'ǤƤη֥ɽˡꤷޤʤƤɽˤʤ褦ꤷƤ';
$string['explain_timeformat'] = '֤ɽ12ɽޤ24ɽ򤹤뤳ȤǤޤǥեȤ򤷤ϡѸ˹碌ƥեޥåȤưŪ򤵤ޤ';
$string['fri'] = '';
$string['friday'] = '';
$string['globalevents'] = 'ΤΥ٥';
$string['gotocalendar'] = 'ذư';
$string['groupevents'] = '롼ץ٥';
$string['hidden'] = 'ɽ';
$string['manyevents'] = '$a ٥';
$string['mon'] = '';
$string['monday'] = '';
$string['monthlyview'] = 'ɽ';
$string['newevent'] = '٥';
$string['noupcomingevents'] = 'ľΥ٥ȤϤޤ';
$string['oneevent'] = '1 ٥';
$string['pref_lookahead'] = 'ľᥤ٥Ȥϰ';
$string['pref_maxevents'] = 'ľᥤ٥Ȥκɽ';
$string['pref_persistflt'] = 'ե륿򵭲';
$string['pref_startwday'] = 'ν';
$string['pref_timeformat'] = '֥եޥå';
$string['preferences'] = '';
$string['preferences_available'] = 'Ŀ';
$string['repeateditall'] = 'ѹƤƤ $a ֤٥ȤŬѤ롣';
$string['repeateditthis'] = 'ѹƤ򤳤Υ٥ȤΤߤŬѤ롣';
$string['repeatnone'] = '̵֤';
$string['repeatweeksl'] = '轵٥ȿ';
$string['repeatweeksr'] = '';
$string['sat'] = '';
$string['saturday'] = '';
$string['shown'] = 'ɽ';
$string['spanningevents'] = 'ʹ楤٥';
$string['sun'] = '';
$string['sunday'] = '';
$string['thu'] = '';
$string['thursday'] = '';
$string['timeformat_12'] = '12 ( / )';
$string['timeformat_24'] = '24';
$string['today'] = '';
$string['tomorrow'] = '';
$string['tt_deleteevent'] = '٥Ȥκ';
$string['tt_editevent'] = '٥ȤԽ';
$string['tt_hidecourse'] = '٥ȤɽǤ (  åɽ  )';
$string['tt_hideglobal'] = 'ΤΥ٥ȤɽǤ (  åɽ  )';
$string['tt_hidegroups'] = '롼ץ٥ȤɽǤ (  åɽ  )';
$string['tt_hideuser'] = '桼٥ȤɽǤ (  åɽ  )';
$string['tt_showcourse'] = '٥ȤɽǤ(  åɽ  )';
$string['tt_showglobal'] = 'ΤΥ٥ȤɽǤ (  åɽ  )';
$string['tt_showgroups'] = '롼ץ٥ȤɽǤ (  åɽ  )';
$string['tt_showuser'] = '桼٥ȤɽǤ (  åɽ  )';
$string['tue'] = '';
$string['tuesday'] = '';
$string['typecourse'] = '٥';
$string['typegroup'] = '롼ץ٥';
$string['typesite'] = 'ȥ٥';
$string['typeuser'] = '桼٥';
$string['upcomingevents'] = 'ľᥤ٥';
$string['userevents'] = '桼٥';
$string['wed'] = '';
$string['wednesday'] = '';
$string['yesterday'] = '';
$string['youcandeleteallrepeats'] = 'Υ٥ȤϷ֤٥ȤΰǤʤϤΥ٥ȤΤߤ뤳ȤǤޤ٤Ƥ $a ٥Ȥ뤳ȤǤޤ';

?>
